@@ -3,6 +3,7 @@ from typing import List
 from deckz.builder import Builder
 from deckz.config import get_config
 from deckz.paths import Paths
+from deckz.settings import Settings
 from deckz.targets import Targets
 
 
@@ -15,8 +16,10 @@ def run(
 ) -> None:
     config = get_config(paths)
     targets = Targets(paths=paths, fail_on_missing=True, whitelist=target_whitelist)
+    settings = Settings(paths)
     Builder(
         config,
+        settings,
         paths,
         targets,
         build_handout=build_handout,
